@@ -5,7 +5,7 @@
 # from a C++ header
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/05/31 01:43:26 $
+# Last Updated: $Date: 2003/08/27 23:55:51 $
 # 
 # Copyright (c) 1999-2001 Apple Computer, Inc.  All Rights Reserved.
 # The contents of this file constitute Original Code as defined in and are
@@ -289,6 +289,7 @@ sub _getCompositePageString {
     my $name = $self->name();
     my $compositePageString;
     my $contentString;
+    my $list_attributes = $self->getAttributeLists();
     
     my $abstract = $self->abstract();
     if (length($abstract)) {
@@ -296,15 +297,52 @@ sub _getCompositePageString {
 	    $compositePageString .= $abstract;
     }
 
+    my $namespace = $self->namespace();
+    my $availability = $self->availability();
+    my $updated = $self->updated();
+
+    if (length($namespace) || length($updated) || length($availability)) {
+	    $compositePageString .= "<p></p>\n";
+    }
+
+    if (length($namespace)) {
+	    $compositePageString .= "<b>Namespace:</b> $namespace<br>\n";
+    }
+    if (length($availability)) {
+	    $compositePageString .= "<b>Availability:</b> $availability<br>\n";
+    }
+    if (length($updated)) {
+	    $compositePageString .= "<b>Updated:</b> $updated<br>\n";
+    }
+
+    if (length($list_attributes)) {
+	$contentString .= $list_attributes;
+    }
+
+
+    my $short_attributes = $self->getAttributes(0);
+    my $long_attributes = $self->getAttributes(1);
+    my $list_attributes = $self->getAttributeLists();
+    if (length($short_attributes)) {
+            $compositePageString .= "$short_attributes";
+    }
+    if (length($list_attributes)) {
+            $compositePageString .= "$list_attributes";
+    }
+
     my $discussion = $self->discussion();
     if (length($discussion)) {
 	    $compositePageString .= "<h2>Discussion</h2>\n";
 	    $compositePageString .= $discussion;
     }
-    
-    if ((length($abstract)) || (length($discussion))) {
-	    $compositePageString .= "<hr><br>";
+    if (length($long_attributes)) {
+            $compositePageString .= "$long_attributes";
     }
+    
+    # if ((length($long_attributes)) || (length($discussion))) {
+    # ALWAYS....
+	    $compositePageString .= "<hr><br>";
+    # }
 
     $contentString= $self->_getFunctionDetailString();
     if (length($contentString)) {
@@ -372,17 +410,25 @@ sub _getFunctionDetailString {
         my $desc = $obj->discussion();
 	my $throws = $obj->throws();
         my $abstract = $obj->abstract();
+        my $availability = $obj->availability();
         my $updated = $obj->updated();
         my $declaration = $obj->declarationInHTML();
         my $declarationRaw = $obj->declaration();
         my $accessControl = $obj->accessControl();
         my @params = $obj->taggedParameters();
         my $result = $obj->result();
+	my $list_attributes = $obj->getAttributeLists();
+
 	$contentString .= "<hr>";
 	# if ($declaration !~ /#define/) { # not sure how to handle apple_refs with macros yet
 	        my $paramSignature = $self->getParamSignature($declarationRaw);
 	        my $methodType = $self->getMethodType($declarationRaw);
-        	$contentString .= "<a name=\"//$apiUIDPrefix/cpp/$methodType/$className/$name/$paramSignature\"></a>\n";
+        	my $uid = "//$apiUIDPrefix/cpp/$methodType/$className/$name/$paramSignature";
+		if ($obj->checkAttributeLists("Template Field")) {
+        	    $uid = "//$apiUIDPrefix/cpp/ftmplt/$className/$name/$paramSignature";
+		}
+		HeaderDoc::APIOwner->register_uid($uid);
+        	$contentString .= "<a name=\"$uid\"></a>\n";
         # }
 	$contentString .= "<table border=\"0\"  cellpadding=\"2\" cellspacing=\"2\" width=\"300\">";
 	$contentString .= "<tr>";
@@ -399,10 +445,17 @@ sub _getFunctionDetailString {
             # $contentString .= "<b>Abstract:</b> $abstract<BR>\n";
             $contentString .= "$abstract<BR>\n";
         }
+	if (length($availability)) {
+	    $contentString .= "<b>Availability:</b> $availability<BR>\n";
+	}
 	if (length($updated)) {
 	    $contentString .= "<b>Updated:</b> $updated<BR>\n";
 	}
+	if (length($list_attributes)) {
+	    $contentString .= $list_attributes;
+	}
         $contentString .= "<blockquote><pre><tt>$accessControl</tt>\n<br>$declaration</pre></blockquote>\n";
+        if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
 	    my $arrayLength = @params;
 	    if ($arrayLength > 0) {
 	        my $paramContentString;
@@ -410,22 +463,24 @@ sub _getFunctionDetailString {
 	            my $pName = $element->name();
 	            my $pDesc = $element->discussion();
 	            if (length ($pName)) {
-	                $paramContentString .= "<tr><td align=\"center\"><tt>$pName</tt></td><td>$pDesc</td></tr>\n";
+	                # $paramContentString .= "<tr><td align=\"center\"><tt>$pName</tt></td><td>$pDesc</td></tr>\n";
+	                $paramContentString .= "<dt><tt><em>$pName</em></tt></dt><dd>$pDesc</dd>\n";
 	            }
 	        }
 	        if (length ($paramContentString)){
-		        $contentString .= "<h4>Parameters</h4>\n";
+		        $contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Parameter Descriptions</font></h5>\n";
 		        $contentString .= "<blockquote>\n";
-		        $contentString .= "<table border=\"1\"  width=\"90%\">\n";
-		        $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
+		        # $contentString .= "<table border=\"1\"  width=\"90%\">\n";
+		        # $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
+			$contentString .= "<dl>\n";
 	            $contentString .= $paramContentString;
-		        $contentString .= "</table>\n</blockquote>\n";
+		        # $contentString .= "</table>\n</blockquote>\n";
+		        $contentString .= "</dl>\n</blockquote>\n";
 		    }
 	    }
 	if (length($result)) {
-            $contentString .= "<b>Result:</b> $result\n";
+            $contentString .= "<dl><dt><i>function result</i></dt><dd>$result</dd></dl>\n";
         }
-	if (length($desc)) {$contentString .= "<p>$desc</p>\n"; }
 	    # $contentString .= "<hr>\n";
     }
     return $contentString;
@@ -435,6 +490,7 @@ sub XMLdocumentationBlock {
     my $self = shift;
     my $compositePageString = "";
     my $name = $self->name();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $abstract = $self->abstract();
     my $discussion = $self->discussion();
@@ -449,6 +505,9 @@ sub XMLdocumentationBlock {
     if (length($abstract)) {
 	$compositePageString .= "<abstract>$abstract</abstract>\n";
     }
+    if (length($availability)) {
+	$contentString .= "<availability>$availability</availability>\n";
+    }
     if (length($updated)) {
 	$contentString .= "<updated>$updated</updated>\n";
     }
@@ -527,6 +586,7 @@ sub _getVarDetailString {
     foreach my $obj (sort objName @varObjs) {
         my $name = $obj->name();
 	my $abstract = $obj->abstract();
+	my $availability = $obj->availability();
 	my $updated = $obj->updated();
         my $desc = $obj->discussion();
         my $declaration = $obj->declarationInHTML();
@@ -535,23 +595,26 @@ sub _getVarDetailString {
         my $fieldHeading;
         if ($obj->can('fields')) { # for Structs and Typedefs
             @fields = $obj->fields();
-            $fieldHeading = "Fields";
+            $fieldHeading = "Field Descriptions";
         } elsif ($obj->can('constants')) { # for enums
             @fields = $obj->constants();
             $fieldHeading = "Constants";
         }
         if ($obj->can('isFunctionPointer')) {
         	if ($obj->isFunctionPointer()) {
-            	$fieldHeading = "Parameters";
+            	$fieldHeading = "Parameter Descriptions";
         	}
         }
 
 	my $methodType = "var"; # $self->getMethodType($declarationRaw);
 	my $apiUIDPrefix = HeaderDoc::APIOwner->apiUIDPrefix();
 	my $headerObject = HeaderDoc::APIOwner->headerObject();
-	my $className = (HeaderDoc::APIOwner->headerObject())->name();
+	# my $className = (HeaderDoc::APIOwner->headerObject())->name();
+	my $className = $self->name();
 	$contentString .= "<hr>";
-	$contentString .= "<a name=\"//$apiUIDPrefix/occ/$methodType/$className/$name\"></a>\n";
+	my $uid = "//$apiUIDPrefix/cpp/$methodType/$className/$name";
+	HeaderDoc::APIOwner->register_uid($uid);
+	$contentString .= "<a name=\"$uid\"></a>\n";
         
 	$contentString .= "<table border=\"0\"  cellpadding=\"2\" cellspacing=\"2\" width=\"300\">";
 	$contentString .= "<tr>";
@@ -564,27 +627,34 @@ sub _getVarDetailString {
 		# $contentString .= "<b>Abstract:</b> $abstract<BR>\n";
 		$contentString .= "$abstract<BR>\n";
 	}
+	if (length($availability)) {
+		$contentString .= "<b>Availability:</b> $availability<BR>\n";
+	}
 	if (length($updated)) {
 		$contentString .= "<b>Updated:</b> $updated<BR>\n";
 	}
         $contentString .= "<blockquote><tt>$accessControl</tt> $declaration</blockquote>\n";
-        $contentString .= "<p>$desc</p>\n";
+        if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
+        # $contentString .= "<p>$desc</p>\n";
 	    my $arrayLength = @fields;
 	    if ($arrayLength > 0) {
-	        $contentString .= "<h4>$fieldHeading</h4>\n";
+	        $contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">$fieldHeading</font></h5>\n";
 	        $contentString .= "<blockquote>\n";
-	        $contentString .= "<table border=\"1\"  width=\"90%\">\n";
-	        $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
+	        # $contentString .= "<table border=\"1\"  width=\"90%\">\n";
+	        # $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
+		$contentString .= "<dl>\n";
 	        foreach my $element (@fields) {
 	            my $fName = $element->name();
 	            my $fDesc = $element->discussion();
-	            $contentString .= "<tr><td align=\"center\"><tt>$fName</tt></td><td>$fDesc</td></tr>\n";
+	            # $contentString .= "<tr><td align=\"center\"><tt>$fName</tt></td><td>$fDesc</td></tr>\n";
+	            $contentString .= "<dt><tt>$fName</tt></dt><dd>$fDesc</dd>\n";
 	        }
-	        $contentString .= "</table>\n</blockquote>\n";
-	    }
-	    if (length($updated)) {
-		$contentString .= "<b>Updated:</b> $updated\n";
+	        # $contentString .= "</table>\n</blockquote>\n";
+	        $contentString .= "</dl>\n</blockquote>\n";
 	    }
+	    # if (length($updated)) {
+		# $contentString .= "<b>Updated:</b> $updated\n";
+	    # }
 	    $contentString .= "<hr>\n";
     }
     return $contentString;
@@ -626,6 +696,10 @@ sub docNavigatorComment {
     my $name = $self->name();
     my $navComment = "<!-- headerDoc=cl; name=$name-->";
     my $appleRef = "<a name=\"//apple_ref/cpp/cl/$name\"></a>";
+
+    if ($self->fields) {
+	$appleRef = "<a name=\"//apple_ref/cpp/tmplt/$name\"></a>";
+    }
     
     return "$navComment\n$appleRef";
 }
@@ -636,19 +710,31 @@ sub docNavigatorComment {
 sub objName { # used for sorting
    my $obj1 = $a;
    my $obj2 = $b;
-   return ($obj1->name() cmp $obj2->name());
+   if ($HeaderDoc::sort_entries) {
+        return ($obj1->name() cmp $obj2->name());
+   } else {
+        return (1 cmp 2);
+   }
 }
 
 sub byLinkage { # used for sorting
    my $obj1 = $a;
    my $obj2 = $b;
-   return ($obj1->linkageState() cmp $obj2->linkageState());
+   if ($HeaderDoc::sort_entries) {
+        return ($obj1->linkageState() cmp $obj2->linkageState());
+   } else {
+        return (1 cmp 2);
+   }
 }
 
 sub byAccessControl { # used for sorting
    my $obj1 = $a;
    my $obj2 = $b;
-   return ($obj1->accessControl() cmp $obj2->accessControl());
+   if ($HeaderDoc::sort_entries) {
+        return ($obj1->accessControl() cmp $obj2->accessControl());
+   } else {
+        return (1 cmp 2);
+   }
 }
 
 sub linkageAndObjName { # used for sorting
@@ -656,7 +742,11 @@ sub linkageAndObjName { # used for sorting
    my $obj2 = $b;
    my $linkAndName1 = $obj1->linkageState() . $obj1->name();
    my $linkAndName2 = $obj2->linkageState() . $obj2->name();
-   return ($linkAndName1 cmp $linkAndName2);
+   if ($HeaderDoc::sort_entries) {
+        return ($linkAndName1 cmp $linkAndName2);
+   } else {
+        return byLinkage($obj1, $obj2); # (1 cmp 2);
+   }
 }
 
 ##################### Debugging ####################################
