@@ -4,7 +4,7 @@
 # Synopsis: Holds constant info parsed by headerDoc
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/05/31 00:02:49 $
+# Last Updated: $Date: 2003/07/29 20:41:19 $
 # 
 # Copyright (c) 1999 Apple Computer, Inc.  All Rights Reserved.
 # The contents of this file constitute Original Code as defined in and are
@@ -54,8 +54,9 @@ sub processConstantComment {
             };
             ($field =~ s/^abstract\s+//) && do {$self->abstract($field); last SWITCH;};
             ($field =~ s/^discussion\s+//) && do {$self->discussion($field); last SWITCH;};
+            ($field =~ s/^availability\s+//) && do {$self->availability($field); last SWITCH;};
             ($field =~ s/^updated\s+//) && do {$self->updated($field); last SWITCH;};
-	    my $filename = $HeaderDoc::headerObject->name();
+	    my $filename = $HeaderDoc::headerObject->filename();
             print "$filename:0:Unknown field in constant comment: $field\n";
 		}
 	}
@@ -85,13 +86,16 @@ sub documentationBlock {
     my $contentString;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my $apiUIDPrefix = HeaderDoc::APIOwner->apiUIDPrefix();
     
     $contentString .= "<hr>";
-    $contentString .= "<a name=\"//$apiUIDPrefix/c/data/$name\"></a>\n"; # apple_ref marker
+    my $uid = "//$apiUIDPrefix/c/data/$name";
+    HeaderDoc::APIOwner->register_uid($uid);
+    $contentString .= "<a name=\"$uid\"></a>\n"; # apple_ref marker
     $contentString .= "<table border=\"0\"  cellpadding=\"2\" cellspacing=\"2\" width=\"300\">";
     $contentString .= "<tr>";
     $contentString .= "<td valign=\"top\" height=\"12\" colspan=\"5\">";
@@ -100,14 +104,18 @@ sub documentationBlock {
     $contentString .= "</tr></table>";
     $contentString .= "<hr>";
     if (length($abstract)) {
-        # $contentString .= "<b>Abstract:</b> $abstract\n";
-        $contentString .= "$abstract\n";
+        # $contentString .= "<b>Abstract:</b> $abstract<br>\n";
+        $contentString .= "$abstract<br>\n";
+    }
+    if (length($availability)) {
+        $contentString .= "<b>Availability:</b> $availability<br>\n";
     }
     if (length($updated)) {
-        $contentString .= "<b>Updated:</b> $updated\n";
+        $contentString .= "<b>Updated:</b> $updated<br>\n";
     }
     $contentString .= "<blockquote>$declaration</blockquote>\n";
-    $contentString .= "<p>$desc</p>\n";
+    # $contentString .= "<p>$desc</p>\n";
+    if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
     # $contentString .= "<hr>\n";
     return $contentString;
 }
@@ -117,16 +125,22 @@ sub XMLdocumentationBlock {
     my $contentString;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my $apiUIDPrefix = HeaderDoc::APIOwner->apiUIDPrefix();
     
-    $contentString .= "<const id=\"//$apiUIDPrefix/c/data/$name\">\n"; # apple_ref marker
+    my $uid = "//$apiUIDPrefix/c/data/$name";
+    HeaderDoc::APIOwner->register_uid($uid);
+    $contentString .= "<const id=\"$uid\">\n"; # apple_ref marker
     $contentString .= "<name>$name</name>\n";
     if (length($abstract)) {
         $contentString .= "<abstract>$abstract</abstract>\n";
     }
+    if (length($availability)) {
+        $contentString .= "<availability>$availability</availability>\n";
+    }
     if (length($updated)) {
         $contentString .= "<updated>$updated</updated>\n";
     }
