@@ -4,7 +4,7 @@
 # Synopsis: Holds struct info parsed by headerDoc
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/05/31 00:02:49 $
+# Last Updated: $Date: 2003/07/29 20:41:19 $
 # 
 # Copyright (c) 1999 Apple Computer, Inc.  All Rights Reserved.
 # The contents of this file constitute Original Code as defined in and are
@@ -85,6 +85,7 @@ sub processEnumComment {
             };
             ($field =~ s/^abstract\s+//) && do {$self->abstract($field); last SWITCH;};
             ($field =~ s/^discussion\s+//) && do {$self->discussion($field); last SWITCH;};
+            ($field =~ s/^availability\s+//) && do {$self->availability($field); last SWITCH;};
             ($field =~ s/^updated\s+//) && do {$self->updated($field); last SWITCH;};
             ($field =~ s/^constant\s+//) && 
             do {
@@ -104,7 +105,7 @@ sub processEnumComment {
 		}
                 last SWITCH;
             };
-	    my $filename = $HeaderDoc::headerObject->name();
+	    my $filename = $HeaderDoc::headerObject->filename();
             print "$filename:0:Unknown field: $field\n";
 		}
 	}
@@ -132,6 +133,7 @@ sub documentationBlock {
     my $self = shift;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
@@ -140,7 +142,9 @@ sub documentationBlock {
     my $apiUIDPrefix = HeaderDoc::APIOwner->apiUIDPrefix();
     
     $contentString .= "<hr>";
-    $contentString .= "<a name=\"//$apiUIDPrefix/c/tag/$name\"></a>\n"; # apple_ref marker
+    my $uid = "//$apiUIDPrefix/c/tag/$name";
+    HeaderDoc::APIOwner->register_uid($uid);
+    $contentString .= "<a name=\"$uid\"></a>\n"; # apple_ref marker
     $contentString .= "<table border=\"0\"  cellpadding=\"2\" cellspacing=\"2\" width=\"300\">";
     $contentString .= "<tr>";
     $contentString .= "<td valign=\"top\" height=\"12\" colspan=\"5\">";
@@ -150,25 +154,34 @@ sub documentationBlock {
     $contentString .= "<hr>";
     if (length($abstract)) {
         # $contentString .= "<b>Abstract:</b> $abstract\n";
-        $contentString .= "$abstract\n";
+        $contentString .= "$abstract<br>\n";
+    }
+    if (length($availability)) {
+        $contentString .= "<b>Availability:</b> $availability<br>\n";
     }
     if (length($updated)) {
-        $contentString .= "<b>Updated:</b> $updated\n";
+        $contentString .= "<b>Updated:</b> $updated<br>\n";
     }
     $contentString .= "<blockquote>$declaration</blockquote>\n";
-    $contentString .= "<p>$desc</p>\n";
+    # $contentString .= "<p>$desc</p>\n";
+    if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
     my $arrayLength = @constants;
     if ($arrayLength > 0) {
         $contentString .= "<h4>Constants</h4>\n";
         $contentString .= "<blockquote>\n";
-        $contentString .= "<table border=\"1\"  width=\"90%\">\n";
-        $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
+	$contentString .= "<dl>\n";
+        # $contentString .= "<table border=\"1\"  width=\"90%\">\n";
+        # $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
         foreach my $element (@constants) {
             my $cName = $element->name();
             my $cDesc = $element->discussion();
-            $contentString .= "<tr><td align=\"center\"><a name=\"//$apiUIDPrefix/c/econst/$cName\"><tt>$cName</tt></a></td><td>$cDesc</td></tr>\n";
+            my $uid = "//$apiUIDPrefix/c/econst/$cName";
+	    HeaderDoc::APIOwner->register_uid($uid);
+            # $contentString .= "<tr><td align=\"center\"><a name=\"$uid\"><tt>$cName</tt></a></td><td>$cDesc</td></tr>\n";
+            $contentString .= "<dt><a name=\"$uid\"><tt>$cName</tt></a></dt><dd>$cDesc</dd>\n";
         }
-        $contentString .= "</table>\n</blockquote>\n";
+        # $contentString .= "</table>\n</blockquote>\n";
+        $contentString .= "</dl>\n</blockquote>\n";
     }
     # $contentString .= "<hr>\n";
     return $contentString;
@@ -178,6 +191,7 @@ sub XMLdocumentationBlock {
     my $self = shift;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
@@ -185,11 +199,16 @@ sub XMLdocumentationBlock {
     my $contentString;
     my $apiUIDPrefix = HeaderDoc::APIOwner->apiUIDPrefix();
     
-    $contentString .= "<enum id=\"//$apiUIDPrefix/c/tag/$name\">\n"; # apple_ref marker
+    my $uid = "//$apiUIDPrefix/c/tag/$name";
+    HeaderDoc::APIOwner->register_uid($uid);
+    $contentString .= "<enum id=\"$uid\">\n"; # apple_ref marker
     $contentString .= "<name>$name</name>\n";
     if (length($abstract)) {
         $contentString .= "<abstract>$abstract</abstract>\n";
     }
+    if (length($availability)) {
+        $contentString .= "<availability>$availability</availability>\n";
+    }
     if (length($updated)) {
         $contentString .= "<updated>$updated</updated>\n";
     }
@@ -201,7 +220,9 @@ sub XMLdocumentationBlock {
         foreach my $element (@constants) {
             my $cName = $element->name();
             my $cDesc = $element->discussion();
-            $contentString .= "<constant id=\"//$apiUIDPrefix/c/econst/$cName\">\n";
+            my $uid = "//$apiUIDPrefix/c/econst/$cName";
+	    HeaderDoc::APIOwner->register_uid($uid);
+            $contentString .= "<constant id=\"$uid\">\n";
 	    $contentString .= "<name>$cName</name>\n";
 	    $contentString .= "<description>$cDesc</description>\n";
 	    $contentString .= "</constant>\n";
