@@ -5,7 +5,7 @@
 #           are used to comment symbolic constants declared with #define
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/05/31 00:02:49 $
+# Last Updated: $Date: 2003/07/29 20:41:19 $
 # 
 # Copyright (c) 1999 Apple Computer, Inc.  All Rights Reserved.
 # The contents of this file constitute Original Code as defined in and are
@@ -43,6 +43,7 @@ sub processPDefineComment {
             ($field =~ s/^define(d)?\s+//) && do {$self->name($field); last SWITCH;};
             ($field =~ s/^abstract\s+//) && do {$self->abstract($field); last SWITCH;};
             ($field =~ s/^discussion\s+//) && do {$self->discussion($field); last SWITCH;};
+            ($field =~ s/^availability\s+//) && do {$self->availability($field); last SWITCH;};
             ($field =~ s/^updated\s+//) && do {$self->updated($field); last SWITCH;};
 	    my $filename = $HeaderDoc::headerObject->name();
             print "$filename:0:Unknown field: $field\n";
@@ -75,12 +76,13 @@ sub documentationBlock {
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $contentString;
 
     # add apple_ref markup
 
-    my $methodType = "defn"; # $self->getMethodType($declarationRaw);
+    my $methodType = "macro"; # $self->getMethodType($declarationRaw);
     $contentString .= "<hr>";
     $contentString .= $self->appleref($methodType);
 
@@ -94,14 +96,18 @@ sub documentationBlock {
     $contentString .= "</tr></table>";
     $contentString .= "<hr>";
     if (length($abstract)) {
-        # $contentString .= "<b>Abstract:</b> $abstract\n";
-        $contentString .= "$abstract\n";
+        # $contentString .= "<b>Abstract:</b> $abstract<br>\n";
+        $contentString .= "$abstract<br>\n";
+    }
+    if (length($availability)) {
+        $contentString .= "<b>Availability:</b> $availability<br>\n";
     }
     if (length($updated)) {
-        $contentString .= "<b>Updated:</b> $updated\n";
+        $contentString .= "<b>Updated:</b> $updated<br>\n";
     }
     $contentString .= "<blockquote>$declaration</blockquote>\n";
-    $contentString .= "<p>$desc</p>\n";
+    if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
+    # $contentString .= "<p>$desc</p>\n";
     # $contentString .= "<hr>\n";
     return $contentString;
 }
@@ -112,6 +118,7 @@ sub XMLdocumentationBlock {
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $contentString;
  
@@ -119,6 +126,9 @@ sub XMLdocumentationBlock {
     if (length($abstract)) {
         $contentString .= "<abstract>$abstract</abstract>\n";
     }
+    if (length($availability)) {
+        $contentString .= "<availability>$availability</availability>\n";
+    }
     if (length($updated)) {
         $contentString .= "<updated>$updated</updated>\n";
     }
