@@ -4,7 +4,7 @@
 # Synopsis: Holds class and instance data members parsed by headerDoc
 #
 # Author: Matt Morse (matt@apple.com)
-# Last Updated: $Date: 2003/05/31 00:02:49 $
+# Last Updated: $Date: 2003/09/03 01:47:59 $
 # 
 # Copyright (c) 1999 Apple Computer, Inc.  All Rights Reserved.
 # The contents of this file constitute Original Code as defined in and are
@@ -14,7 +14,7 @@
 # read it before using this file.
 #
 # This Original Code and all software distributed under the License are
-# distributed on an TAS ISU basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+# distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 # EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 # INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY, FITNESS
 # FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the License for
@@ -50,6 +50,7 @@ sub processVarComment {
                 last SWITCH;
             };
             ($field =~ s/^abstract\s+//) && do {$self->abstract($field); last SWITCH;};
+            ($field =~ s/^availability\s+//) && do {$self->availability($field); last SWITCH;};
             ($field =~ s/^updated\s+//) && do {$self->updated($field); last SWITCH;};
             ($field =~ s/^discussion\s+//) && do {$self->discussion($field); last SWITCH;};
 	    my $filename = $HeaderDoc::headerObject->name();
@@ -84,15 +85,16 @@ sub documentationBlock {
     my $contentString;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my @fields = $self->fields();
-    my $fieldHeading = "Fields";
+    my $fieldHeading = "Field Descriptions";
 
     if ($self->can('isFunctionPointer')) {
         if ($self->isFunctionPointer()) {
-            $fieldHeading = "Parameters";
+            $fieldHeading = "Parameter Descriptions";
         }
     }
 
@@ -113,18 +115,27 @@ sub documentationBlock {
     $contentString .= "</tr></table>";
     $contentString .= "<hr>";
     if (length($abstract)) {
-        # $contentString .= "<b>Abstract:</b> $abstract\n";
+        # $contentString .= "<b>Abstract:</b> $abstract<br>\n";
         $contentString .= "$abstract\n";
     }
+    if (length($availability)) {
+        $contentString .= "<b>Availability:</b> $availability<br>\n";
+    }
     if (length($updated)) {
-        $contentString .= "<b>Updated:</b> $updated\n";
+        $contentString .= "<b>Updated:</b> $updated<br>\n";
     }
     $contentString .= "<blockquote>$declaration</blockquote>\n";
-    $contentString .= "<p>$desc</p>\n";
+    if (length($desc)) {$contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">Discussion</font></h5><p>$desc</p>\n"; }
+    # $contentString .= "<p>$desc</p>\n";
     my $arrayLength = @fields;
     if ($arrayLength > 0) {
-        $contentString .= "<h4>$fieldHeading</h4>\n";
+        $contentString .= "<h5><font face=\"Lucida Grande,Helvetica,Arial\">$fieldHeading</font></h5>\n";
         $contentString .= "<blockquote>\n";
+
+	# DAG Not converting table to definition list because this code can never be
+	# called unless something subclasses Var without overriding this method or unless
+	# someone adds code to parse an @field or @param in the @var tag.
+
         $contentString .= "<table border=\"1\"  width=\"90%\">\n";
         $contentString .= "<thead><tr><th>Name</th><th>Description</th></tr></thead>\n";
         foreach my $element (@fields) {
@@ -147,15 +158,16 @@ sub XMLdocumentationBlock {
     my $contentString;
     my $name = $self->name();
     my $abstract = $self->abstract();
+    my $availability = $self->availability();
     my $updated = $self->updated();
     my $desc = $self->discussion();
     my $declaration = $self->declarationInHTML();
     my @fields = $self->fields();
-    my $fieldHeading = "Fields";
+    my $fieldHeading = "Field Descriptions";
     
     if ($self->can('isFunctionPointer')) {
         if ($self->isFunctionPointer()) {
-            $fieldHeading = "Parameters";
+            $fieldHeading = "Parameter Descriptions";
         }
     }
     
@@ -163,6 +175,9 @@ sub XMLdocumentationBlock {
     if (length($abstract)) {
         $contentString .= "<abstract>$abstract</abstract>\n";
     }
+    if (length($availability)) {
+        $contentString .= "<availability>$availability</availability>\n";
+    }
     if (length($updated)) {
         $contentString .= "<updated>$updated</updated>\n";
     }
